<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi_FI">
<context>
    <name>ConfigureE131</name>
    <message>
        <location filename="configuree131.ui" line="33"/>
        <source>Configure E1.31 Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="43"/>
        <source>Universes Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="56"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="66"/>
        <source>Multicast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="71"/>
        <source>IP Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="76"/>
        <source>Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="81"/>
        <source>E1.31 Universe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="86"/>
        <source>Transmission Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="91"/>
        <source>Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="101"/>
        <source>Seconds to wait for an interface to be ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="61"/>
        <source>Universe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="92"/>
        <source>Inputs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="98"/>
        <source>Outputs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="182"/>
        <source>Full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="183"/>
        <source>Partial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="191"/>
        <source>%1 - min, %2 - default, %3 - max</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="238"/>
        <source>Invalid IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="238"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>E131Plugin</name>
    <message>
        <location filename="e131plugin.cpp" line="97"/>
        <source>This plugin provides DMX output for devices supporting the E1.31 communication protocol.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="144"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="148"/>
        <location filename="e131plugin.cpp" line="287"/>
        <source>Status: Not open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="151"/>
        <location filename="e131plugin.cpp" line="290"/>
        <source>Status: Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="153"/>
        <source>Packets sent: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="283"/>
        <source>Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="292"/>
        <source>Packets received: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
